PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/pseudoprojector.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

pseudoprojector.h
Go to the documentation of this file.
1
5 #ifndef PSEUDOPROJECTOR_H
6 #define PSEUDOPROJECTOR_H
7 #include "utils.h"
8
12 void vc_pseudoprojection(pswf_t* wf_ref, pswf_t* wf_proj, int BAND_NUM, double* results);
13
26 double* pseudoprojection(pswf_t* wf_ref, pswf_t* wf_proj, int BAND_NUM);
27
28 #endif
utils.h
pswf
Definition: utils.h:112
pseudoprojection
double * pseudoprojection(pswf_t *wf_ref, pswf_t *wf_proj, int BAND_NUM)
vc_pseudoprojection
void vc_pseudoprojection(pswf_t *wf_ref, pswf_t *wf_proj, int BAND_NUM, double *results)